
clear all;
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load Abilene data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rand('seed',0);
week = 1;
router = 1; % set to 1 for Atlanta, 9 for Sunnyvale
anom_prct = .95;
% type "help load_abilene" for details
[data, anom_idx_unsorted] = load_abilene(week,router,anom_prct);
N = size(data,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set MN-SCAnn options. Type "help mnscann" for details
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

opts.bandwidth = 0.1; 
opts.n_grid = 3000;
opts.supp_shape = 0;
opts.extreme = 1;
opts.show_roc = 1;
opts.show_iv = 1;
opts.show_smooth = 1;
opts.verbose = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run MN-SCAnn
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

output = mnscann(data,opts);
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Visualize results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% organize data
[gamma_sort,gamma_idx] = sort(output.gammas);
beta_sort = sort(output.betas);
extreme_idx = find(output.extreme(gamma_idx));
nonextreme_idx = find(~output.extreme(gamma_idx));
anom_idx_sorted = find(ismember(gamma_idx,anom_idx_unsorted));

% plot annotation values and indicate anomalies
figure
plot(gamma_sort,'.') % plot gamma curve
%plot(nonextreme_idx,gamma_sort(nonextreme_idx),'.') % plot gamma curve
hold on
stem(anom_idx_sorted,gamma_sort(anom_idx_sorted))
axis([800 1009 0 1])
warning off; % warning issued if extreme points not plotted
legend('gammas','anomalies','Location','NorthWest'); 
warning on
xlabel('Index of ranked points')
ylabel('Annotation')

